==> agschat-0.0.5.tar.gz: lib/src/helper/utilites.dart <==
import 'package:intl/intl.dart';
import 'package:rxdart/rxdart.dart';

class Utilities {
  static String convertTimeStampToDate(timeStamp, {formate}) {
    final DateTime selDate =
        DateTime.fromMillisecondsSinceEpoch(timeStamp * 1000);
    print(selDate);
    final DateFormat formatter =
        DateFormat(formate == null ? 'dd/MM/yy' : formate);

    final String formatted = formatter.format(selDate);
    return formatted;
  }

  static String convertTimeStampToTime(timeStamp) {
    final DateTime selDate =
        DateTime.fromMillisecondsSinceEpoch(timeStamp * 1000);
    // print(selDate);
    var getDate = DateFormat.yMd().add_jm().format(selDate);
    ;
    var timeSplit = getDate.split(" ");
    print(timeSplit[1]);
    return timeSplit[1] + timeSplit[2];
  }
}

class ChatDateFormatter {
  ChatDateFormatter();

  String groupChatDateHeader(value) {
    print('value $value');
    DateTime tempDate = DateFormat('yyyy-MM-dd').parse(value);
    String date;
    if (tempDate.day == DateTime.now().day) {
      date = 'Today';
    } else if (tempDate.day == DateTime.now().day - 1) {
      date = 'Yesterday';
    } else
      date = DateFormat('dd MMM yyyy').format(tempDate);
    print('formattedDate : $date');
    return date;
  }

  String getVerboseDateTimeRepresentation(DateTime dateTime) {
    DateTime now = DateTime.now();
    DateTime justNow = now.subtract(Duration(minutes: 1));
    DateTime localDateTime = dateTime.toLocal();

    if (!localDateTime.difference(justNow).isNegative) {
      return 'Just Now';
    }

    String roughTimeString = DateFormat('jm').format(dateTime);

    if (localDateTime.day == now.day &&
        localDateTime.month == now.month &&
        localDateTime.year == now.year) {
      return roughTimeString;
    }

    DateTime yesterday = now.subtract(Duration(days: 1));

    if (localDateTime.day == yesterday.day &&
        localDateTime.month == now.month &&
        localDateTime.year == now.year) {
      String roughTime = DateFormat('jm').format(dateTime);
      return 'Yesterday $roughTime';
    }

    if (now.difference(localDateTime).inDays < 4) {
      String weekday = DateFormat(
        'EEEE',
      ).format(localDateTime);

      return '$weekday, $roughTimeString';
    }

    return '${DateFormat(
      'yMd',
    ).format(dateTime)}, $roughTimeString';
  }
}

==> agschat-0.0.27.tar.gz: lib/src/helper/utilites.dart <==
import 'package:intl/intl.dart';

class Utilities {
  static String convertTimeStampToDate(timeStamp, {formate}) {
    final DateTime selDate =
        DateTime.fromMillisecondsSinceEpoch(timeStamp * 1000);
    print(selDate);
    final DateFormat formatter =
        DateFormat(formate == null ? 'dd/MM/yy' : formate);

    final String formatted = formatter.format(selDate);
    return formatted;
  }

  static String convertTimeStampToTime(timeStamp) {
    final DateTime selDate =
        DateTime.fromMillisecondsSinceEpoch(timeStamp * 1000);
    // print(selDate);
    var getDate = DateFormat.yMd().add_jm().format(selDate);
    ;
    var timeSplit = getDate.split(" ");
    print(timeSplit[1]);
    return timeSplit[1] + timeSplit[2];
  }
}

class ChatDateFormatter {
  ChatDateFormatter();

  String groupChatDateHeader(value) {
    print('value $value');
    DateTime tempDate = DateFormat('yyyy-MM-dd').parse(value);
    String date;
    if (tempDate.day == DateTime.now().day) {
      date = 'Today';
    } else if (tempDate.day == DateTime.now().day - 1) {
      date = 'Yesterday';
    } else {
      date = DateFormat('dd MMM yyyy').format(tempDate);
    }
    print('formattedDate : $date');
    return date;
  }

  String getVerboseDateTimeRepresentation(DateTime dateTime) {
    DateTime now = DateTime.now();
    DateTime justNow = now.subtract(const Duration(minutes: 1));
    DateTime localDateTime = dateTime.toLocal();

    if (!localDateTime.difference(justNow).isNegative) {
      return 'Just Now';
    }

    String roughTimeString = DateFormat('jm').format(dateTime);

    if (localDateTime.day == now.day &&
        localDateTime.month == now.month &&
        localDateTime.year == now.year) {
      return roughTimeString;
    }

    DateTime yesterday = now.subtract(Duration(days: 1));

    if (localDateTime.day == yesterday.day &&
        localDateTime.month == now.month &&
        localDateTime.year == now.year) {
      String roughTime = DateFormat('jm').format(dateTime);
      return 'Yesterday $roughTime';
    }

    if (now.difference(localDateTime).inDays < 4) {
      String weekday = DateFormat(
        'EEEE',
      ).format(localDateTime);

      return '$weekday, $roughTimeString';
    }

    return '${DateFormat(
      'yMd',
    ).format(dateTime)}, $roughTimeString';
  }
}
